@@ -563,7 +563,7 @@ class Submission(Base):
     posted_at = Column(DateTime)
 
     # Неизвестное поле
-    cached_quiz_lti = Column(Boolean)
+    cached_quiz_lti = Column(Boolean, default=False)
 
     # Неизвестное поле
     cached_tardiness = Column(String(16))
@@ -577,7 +577,7 @@ class Submission(Base):
     root_account = relationship('Account')
 
     # Неизвестное поле
-    redo_request = Column(Boolean)
+    redo_request = Column(Boolean, default=False)
 
     # Неизвестное поле
     resource_link_lookup_uuid = Column(String(255))
